@@ -2,7 +2,7 @@
          implicit none
 !       read a configuration file
 
-      integer :: result
+      real*4 :: result
       character (len=255) :: inbound, inbound_locked
       character (len=30) :: format1
       integer :: err_msg, ready
@@ -10,7 +10,7 @@
       inbound_locked=trim(inbound)//"_locked"
       format1= "(F5.1)"
 
-!      print *, 'read_thickness_m_file.f, inbound is:', trim(inbound)
+!      print *,'read_thickness_m_file.f, inbound is:',trim(inbound)
 !      in case inbound is of a different, but shorter length in main
 !      create a temporary, new, lock file
 10     open(status='new',unit=30,file=inbound_locked,iostat=ready)
@@ -21,11 +21,11 @@
          if (err_msg.eq.0) then
 
           read (29,format1) result
-          print *, 'read_thickness_m_file.f, result',result
+ !         print *, 'read_thickness_m_file.f, result',result
           close (unit=29)
 
          else
-          print *, 'read_thickness_m_file.f,locked, try again,read =',ready
+          print *,'read_thickness_m_file.f,locked,again,read=',ready
 !         rest a little before trying again
 !         call sleep(1)
           go to 10
@@ -39,5 +39,5 @@
         end if
 
        end if
-       print *, 'read_thickness_m_file, result',result
+!       print *, 'read_thickness_m_file, result',result
       end subroutine read_thickness_m_file
