@@ -307,7 +307,7 @@ my $var = {
 	_base_file_name         => 'base_file_name',
 	_clear_text             => '',
 	_color_default          => 'grey',           # first color listbox to select
-	_config_file_format     => '%-35s%1s%-20s',
+	_config_file_format     => '                                                        ',
 	_eight_characters       => '8',
 	_empty_string           => '',
 	_failure                => -1,
@@ -369,7 +369,7 @@ my $var = {
 	_one_character                 => '1',
 	_one_pixel                     => '1',
 	_one_pixel_borderwidth         => '1',
-	_program_title                 => 'SeismicUnixGui V0.82.6',
+	_program_title                 => 'SeismicUnixGui V0.82.8',
 	_project_selector_title        => 'Project Selector',
 	_l_suplot_title                => 'L_suplot',
 	_project_selector_title        => 'Project Selector',
