@@ -1,6 +1,7 @@
 package App::SeismicUnixGui::misc::manage_files_by;
 
 use Moose;
+our $VERSION = '0.0.1';
 
 # manage_files_by  class
 # Contains methods/subroutines/functions to operate on directories
@@ -1315,7 +1316,7 @@ sub write_gather {
 	# WRITE OUT FILE
 
 	# open and write to output file
-	my ( $self, $gather_aref, $DIR_OUT ) = @_;
+	my ( $self, $gather_aref, $DIR_OUT , $gather_type) = @_;
 
 	my ( $i, $number_of_gathers, $number_of_lines );
 
@@ -1327,7 +1328,7 @@ sub write_gather {
 	open( OUT, ">$DIR_OUT/$temp" );
 
 	# print first line
-	print OUT ("gather=");
+	print OUT ("$gather_type=");
 	print OUT ("@$gather_aref[0]");
 
 	for ( $i = 1 ; $i < $number_of_gathers ; $i++ ) {
